pub struct Handle<T> { /* private fields */ }Expand description
Handle is some sort of non-owning reference to content in a pool. It stores index of object and additional information that allows to ensure that handle is still valid (points to the same object as when handle was created).
Implementations
Sourceimpl<T> Handle<T>
impl<T> Handle<T>
pub const NONE: Handle<T>
Sourcepub fn to_base<B>(self) -> Handle<B>where
T: ObjectOrVariant<B>,
pub fn to_base<B>(self) -> Handle<B>where
T: ObjectOrVariant<B>,
Converts the handle to its base variant. In other words, if there are two related types and
A is a variant of B, then this method converts Handle<A> -> Handle<B>.
Sourcepub fn to_variant<V>(self) -> Handle<V>where
V: ObjectOrVariant<T>,
pub fn to_variant<V>(self) -> Handle<V>where
V: ObjectOrVariant<T>,
Converts the handle of a base object to the handle of its variant.
pub fn is_none(self) -> bool
pub fn is_some(self) -> bool
pub fn index(self) -> u32
pub fn generation(self) -> u32
pub fn new(index: u32, generation: u32) -> Self
pub fn transmute<U>(&self) -> Handle<U>
pub fn decode_from_u128(num: u128) -> Self
pub fn encode_to_u128(&self) -> u128