pub struct MultiBorrowContext<'a, const N: usize, T, P = Option<T>>where
    T: Sized,
    P: PayloadContainer<Element = T> + 'static,{ /* private fields */ }
Multi-borrow context allows you to get as many unique references to elements in a pool as you want.

Implementations

source

impl<'a, const N: usize, T, P> MultiBorrowContext<'a, N, T, P>where T: Sized, P: PayloadContainer<Element = T> + 'static,

source

pub fn try_get(&mut self, handle: Handle<T>) -> Option<&'a mut T>

Tries to get a mutable reference to a pool element located at the given handle. The method could fail in three main reasons:

  1. A reference to an element is already taken - returning multiple mutable references to the same element is forbidden by Rust safety rules.
  2. You’re trying to get more references that the context could handle (there is not enough space in the internal handles storage) - in this case you must increase N.
  3. A given handle is invalid.
Performance

This method has O(N) complexity, internally it does linear search in the internal handles storage to enforce borrowing rules at runtime. The method is designed for small reference count (<32), where linear search is faster than hash set.