pub struct RectPacker<T>where
    T: NumAssign + Scalar + PartialOrd + Copy,
{ /* private fields */ }
See module docs.

Implementations

Creates new instance of rectangle packer with given bounds.

How to choose bounds

If you have a set of rectangles and you need to calculate average side length of a square, then calculate total area of your triangles by sum of width*height and then take square root out of area. You’ll get side length of a square which can be used as width and height parameters.

Clears packer and prepares it for another run. It is much cheaper than create new packer, because it reuses previously allocated memory.

Tries to find free place to put rectangle with given size. Returns None if there insufficient space.