pub struct FieldInfo<'a> {
    pub owner_type_id: TypeId,
    pub name: &'static str,
    pub display_name: &'static str,
    pub description: &'static str,
    pub type_name: &'static str,
    pub value: &'a dyn FieldValue,
    pub read_only: bool,
    pub min_value: Option<f64>,
    pub max_value: Option<f64>,
    pub step: Option<f64>,
    pub precision: Option<usize>,
}

Fields

owner_type_id: TypeId

A type id of the owner of the property.

name: &'static str

A name of the property.

display_name: &'static str

A human-readable name of the property.

description: &'static str

Description of the property.

type_name: &'static str

Type name of the property.

value: &'a dyn FieldValue

An reference to the actual value of the property. This is “non-mangled” reference, which means that while field/fields/field_mut/fields_mut might return a reference to other value, than the actual field, the value is guaranteed to be a reference to the real value.

read_only: bool

A property is not meant to be edited.

min_value: Option<f64>

A minimal value of the property. Works only with numeric properties!

max_value: Option<f64>

A minimal value of the property. Works only with numeric properties!

step: Option<f64>

A minimal value of the property. Works only with numeric properties!

precision: Option<usize>

Maximum amount of decimal places for a numeric property.

Implementations

Tries to cast a value to a given type.