FieldMetadata

Struct FieldMetadata 

pub struct FieldMetadata<'s> {
    pub name: &'s str,
    pub display_name: &'s str,
    pub tag: &'s str,
    pub doc: &'s str,
    pub read_only: bool,
    pub immutable_collection: bool,
    pub min_value: Option<f64>,
    pub max_value: Option<f64>,
    pub step: Option<f64>,
    pub precision: Option<usize>,
}

Fields

name: &'s str

A name of the property.

display_name: &'s str

A human-readable name of the property.

tag: &'s str

Tag of the property. Could be used to group properties by a certain criteria or to find a specific property by its tag.

doc: &'s str

Doc comment content.

read_only: bool

A property is not meant to be edited.

immutable_collection: bool

Only for dynamic collections (Vec, etc) - means that its size cannot be changed, however the items of the collection can still be changed.

min_value: Option<f64>

A minimal value of the property. Works only with numeric properties!

max_value: Option<f64>

A minimal value of the property. Works only with numeric properties!

step: Option<f64>

A minimal value of the property. Works only with numeric properties!

precision: Option<usize>

Maximum amount of decimal places for a numeric property.