#[repr(transparent)]
pub struct VariableFlags(_);

Implementations

source

impl VariableFlags

source

pub const F_0: &'static str = _

source

impl VariableFlags

source

pub const NONE: Self = _

Nothing.

source

pub const MODIFIED: Self = _

A variable was externally modified.

source

pub const NEED_SYNC: Self = _

A variable must be synced with respective variable from data model.

source

impl VariableFlags

source

pub const fn empty() -> Self

Returns an empty set of flags.

source

pub const fn all() -> Self

Returns the set containing all flags.

source

pub const fn bits(&self) -> u8

Returns the raw value of the flags currently stored.

source

pub const fn from_bits(bits: u8) -> Option<Self>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

source

pub const fn from_bits_truncate(bits: u8) -> Self

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

source

pub const fn from_bits_retain(bits: u8) -> Self

Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).

source

pub fn from_name(name: &str) -> Option<Self>

Get the value for a flag from its stringified name.

Names are case-sensitive, so must correspond exactly to the identifier given to the flag.

source

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

source

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

source

pub const fn intersects(&self, other: Self) -> bool

Returns true if there are flags common to both self and other.

source

pub const fn contains(&self, other: Self) -> bool

Returns true if all of the flags in other are contained within self.

source

pub fn insert(&mut self, other: Self)

Inserts the specified flags in-place.

This method is equivalent to union.

source

pub fn remove(&mut self, other: Self)

Removes the specified flags in-place.

This method is equivalent to difference.

source

pub fn toggle(&mut self, other: Self)

Toggles the specified flags in-place.

This method is equivalent to symmetric_difference.

source

pub fn set(&mut self, other: Self, value: bool)

Inserts or removes the specified flags depending on the passed value.

source

pub const fn intersection(self, other: Self) -> Self

Returns the intersection between the flags in self and other.

Calculating self bitwise and (&) other, including any bits that don’t correspond to a defined flag.

source

pub const fn union(self, other: Self) -> Self

Returns the union of between the flags in self and other.

Calculates self bitwise or (|) other, including any bits that don’t correspond to a defined flag.

source

pub const fn difference(self, other: Self) -> Self

Returns the difference between the flags in self and other.

Calculates self bitwise and (&!) the bitwise negation of other, including any bits that don’t correspond to a defined flag.

This method is not equivalent to a & !b when there are bits set that don’t correspond to a defined flag. The ! operator will unset any bits that don’t correspond to a flag, so they’ll always be unset by a &! b, but respected by a.difference(b).

source

pub const fn symmetric_difference(self, other: Self) -> Self

Returns the symmetric difference between the flags in self and other.

Calculates self bitwise exclusive or (^) other, including any bits that don’t correspond to a defined flag.

source

pub const fn complement(self) -> Self

Returns the complement of this set of flags.

Calculates the bitwise negation (!) of self, unsetting any bits that don’t correspond to a defined flag.

source

impl VariableFlags

source

pub const fn iter(&self) -> Iter<VariableFlags>

Iterate over enabled flag values.

source

pub const fn iter_names(&self) -> IterNames<VariableFlags>

Iterate over enabled flag values with their stringified names.