Format

Enum Format 

pub enum Format {
    Unknown,
    Binary,
    Ascii,
}
Format of the data that be used by a Visitor instance for reading or writing from/to an external storage.

Variants



Unknown

The format is unknown and unsupported.



Binary

Binary format. The fastest and smallest, but changes cannot be merged by a version control system, thus not suitable for collaborative work. It should be used primarily for production builds.



Ascii

Slow and “fat” format, but changes can be merged by a version control system. It makes this format ideal for collaborative work.