VisitorVersion

Enum VisitorVersion 

#[repr(u32)]
pub enum VisitorVersion { FirstStableRelease = 0, Last = 1, }
Version of the visitor.

Variants



FirstStableRelease = 0

The first stable release of Fyrox 1.0.



Last = 1

^^ Add a new version above this line ^^.

There are few major rules:

  1. New version name should be something like VectorFlattening, and clearly describe the changes introduced by the new version. Always add a doc comment that contains a clear description of what was changed.
  2. Do NOT add explicit number value for a new version. The compiler will do that for you, and there will be no chance of mistake. Legacy variant is an exception.
  3. Existing version entries must NOT be deleted or moved.
  4. Last variant must always be the last.