pub struct Field {
pub name: String,
pub kind: FieldKind,
}Expand description
Values within a visitor are constructed from Fields. Each Field has a name and a value. The name
is used as a key to access the value within the visitor using the crate::Visit::visit method,
so each field within a value must have a unique name.
Fields
name: StringThe key string that allows access to the field.
kind: FieldKindThe data stored in the visitor for this field.
Implementations