pub struct BinaryBlob<'a, T>where
T: Copy,{
pub vec: &'a mut Vec<T>,
}Expand description
Proxy struct for plain data. It is used to serialize arrays of trivially copyable data (Vec<u8>)
directly as a large chunk of data. For example, an attempt to serialize Vec<u8> serialize each
byte as a separate node which is very inefficient.
BinaryBlob stores data very much like crate::visitor::pod::PodVecView except that BinaryBlob
has less type safety. In practice, it is used with T = u8 for Strings and Paths. However,
it accepts any type T that is Copy, and it lacks the type_id system that PodVecView has for
checking that the data it is reading comes from the expected type.
Fields
vec: &'a mut Vec<T>A reference to a vector that represents a binary blob.