Module fyrox_core::math
source · Modules
Structs
Enums
Traits
Functions
Tries to find a point closest to given point.
There are two versions of remainder, the standard
% operator which does x - (x/y).trunc()*y and IEEE remainder which does x - (x/y).round()*y.Returns rotation quaternion that represents rotation basis with Z axis aligned on
vec.
This function handles singularities for you.