pub struct FieldMetadata<'s> {
pub name: &'s str,
pub display_name: &'s str,
pub tag: &'s str,
pub doc: &'s str,
pub read_only: bool,
pub immutable_collection: bool,
pub min_value: Option<f64>,
pub max_value: Option<f64>,
pub step: Option<f64>,
pub precision: Option<usize>,
}Fields
name: &'s strA name of the property.
display_name: &'s strA human-readable name of the property.
tag: &'s strTag of the property. Could be used to group properties by a certain criteria or to find a specific property by its tag.
doc: &'s strDoc comment content.
read_only: boolA property is not meant to be edited.
immutable_collection: boolOnly for dynamic collections (Vec, etc) - means that its size cannot be changed, however the items of the collection can still be changed.
min_value: Option<f64>A minimal value of the property. Works only with numeric properties!
max_value: Option<f64>A minimal value of the property. Works only with numeric properties!
step: Option<f64>A minimal value of the property. Works only with numeric properties!
precision: Option<usize>Maximum amount of decimal places for a numeric property.