Module fyrox_core::variable
source · Expand description
A wrapper for a variable that hold additional flag that tells that initial value was changed in runtime.
For more info see InheritableVariable
Structs
A wrapper for a variable that hold additional flag that tells that initial value was changed in runtime.
A set of possible variable flags.
Enums
An error that could occur during inheritance.
Functions
Simultaneously walks over fields of given child and parent and tries to inherit values of properties
of child with parent’s properties. It is done recursively for every fields in entities.