pub struct BinaryBlob<'a, T>where
T: Copy,{
pub vec: &'a mut Vec<T>,
}Expand description
Proxy struct for plain data, we can’t use Vec<u8> directly,
because it will serialize each byte as separate node.
BinaryBlob stores data very much like PodVecView except that BinaryBlob
has less type safety. In practice it is used with T = u8 for Strings and Paths,
but it accepts any type T that is Copy, and it lacks the type_id system that
PodVecView has for checking that the data it is reading comes from the expected type.
Fields
vec: &'a mut Vec<T>Trait Implementations
Sourceimpl<T> Visit for BinaryBlob<'_, T>
impl<T> Visit for BinaryBlob<'_, T>
Sourcefn visit(&mut self, name: &str, visitor: &mut Visitor) -> VisitResult
fn visit(&mut self, name: &str, visitor: &mut Visitor) -> VisitResult
Read or write this value, depending on whether Visitor::is_reading() is true or false. Read more